@@ -8,7 +8,6 @@ from gateways.apis.api_blueprint_validation import ApiBlueprintValidation
 from gateways.apis.api_catalog import ApiCatalog
 from gateways.apis.api_cost import ApiCost
 from gateways.apis.api_debugging import ApiDebugging
-from gateways.apis.api_integration import ApiIntegration
 from gateways.apis.api_oauth_redirect import ApiOauthRedirect
 from gateways.apis.api_parameter_store import ParameterStore
 from gateways.apis.api_production import ApiProduction
@@ -39,4 +38,3 @@ class ApiRoot:
         self.cost = ApiCost(api_address, version)
         self.debugging = ApiDebugging(api_address, version)
         self.parameterStore = ParameterStore(api_address, version)
-        self.integration = ApiIntegration(api_address, version)
