@@ -5,6 +5,7 @@ from urllib.parse import quote
 
 import time
 from isodate import duration_isoformat
+from requests import Response
 
 from gateways.apis.api_route_base import ApiRoot
 from gateways.common.cs18_api_classes import BlueprintRepositoryDetails, AccessLink, \
@@ -17,7 +18,8 @@ from gateways.common.cs18_api_requests import (
     CreateInvitationsRequest,
     UpdateSpaceRequest,
     ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountInfraSettingsRequest,
-    AddK8SComputeServiceToSpaceRequest, UpdateK8SComputeServiceInSpaceRequest, AwsCloudProviderSettingsModel)
+    AddK8SComputeServiceToSpaceRequest, UpdateK8SComputeServiceInSpaceRequest, AwsCloudProviderSettingsModel,
+    NewUserSurveyRequest)
 from gateways.common.cs18_api_responses import (AccountStatusResponse, BlueprintFileResponse, BlueprintResponse,
                                                 CatalogForGetAllResponse, CatalogForGetResponse, CloudAccountResponse,
                                                 CreateProductionResponse, CreateSandboxResponse, GetSpaceResponse,
@@ -30,7 +32,7 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 BlueprintValidationResponse, AccountRepositoryDetailsResponse,
                                                 DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse,
                                                 ParameterStoreItem, RepositoryProviderResponse,
-                                                RepositoryRelationshipResponse)
+                                                RepositoryRelationshipResponse, AccountExtraDetails)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -245,13 +247,26 @@ class Colony:
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
     # new api
-    def add_k8s_compute_service(self, compute_service_name: str, cloud_account_name: str, agent_namespace: str):
+    def add_k8s_compute_service(self,
+                                compute_service_name: str,
+                                cloud_account_name: str,
+                                agent_namespace: str,
+                                ingress_controller_type: str = None,
+                                ingress_class: str = None,
+                                configure_dns: bool = False,
+                                generate_certificate: bool = False):
         method_url = self._api_root.settings.add_k8s_compute_service_under_cloud_account()
         request = {
             "compute_service_name": compute_service_name,
             "cloud_account_name": cloud_account_name,
-            "agent_namespace": agent_namespace
+            "agent_namespace": agent_namespace,
+            "configure_dns": configure_dns,
+            "generate_certificate": generate_certificate
         }
+        if ingress_controller_type:
+            request["ingress_controller_type"] = ingress_controller_type
+        if ingress_class:
+            request["ingress_class"] = ingress_class
 
         resp = self.session.post(url=method_url, json=request)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
@@ -840,7 +855,7 @@ class Colony:
         GatewayUtils.handle_response(response, [200])
         return json.loads(response.text)
 
-    def create_space(self, space_name: str, cloud_accounts: []):
+    def create_space(self, space_name: str, cloud_accounts: List[str] = None):
         url = self._api_root.spaces.spaces()
         request = {"name": space_name, "cloud_accounts": cloud_accounts}
 
@@ -1086,11 +1101,11 @@ class Colony:
                                                          "sso_update_enabled": sso_update_enabled}
                          , return_codes=[200])
 
-    def get_account_extra_details(self, account_name: str):
-        set_account_extra_details_url = self._api_root.account.set_account_extra_details(account_name)
-        response = self.session.get(url=set_account_extra_details_url)
+    def get_account_extra_details(self, account_name: str) -> AccountExtraDetails:
+        get_account_extra_details_url = self._api_root.account.get_account_extra_details(account_name)
+        response = self.session.get(url=get_account_extra_details_url)
         GatewayUtils.handle_response(response, [200])
-        return json.loads(response.text)
+        return Converters.create_account_extra_details(json=json.loads(response.text))
 
     def get_space_cloud_account_regions(self, space_name: str, cloud_account_name: str) -> List[RegionResponse]:
         method_url = self._api_root.spaces.space_cloud_account_regions(space_name=space_name,
@@ -1197,13 +1212,6 @@ class Colony:
         response_json = json.loads(response.text)
         return Converters.aws_cloud_provider_settings_model(data=response_json)
 
-    def get_insided_token(self):
-        method_url = self._api_root.integration.get_insided_token()
-        response = self.session.get(url=method_url)
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-        response_json = json.loads(response.text)
-        return Converters.insided_token_model(data=response_json)
-
     def add_repository_provider_to_account(
             self,
             provider_name: str,
@@ -1381,6 +1389,13 @@ class Colony:
         resp = self.session.delete(url=method_url)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
+    def submit_new_user_survey(self, survey: NewUserSurveyRequest) -> Response:
+        method_url = self._api_root.account.submit_new_user_survey()
+        resp = self.session.post(url=method_url, json=survey.__dict__)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+
+        return resp
+
 
 class SandboxesHandler:
     def __init__(self):
