@@ -3,55 +3,44 @@ from datetime import datetime
 import dateutil.parser
 from gateways.common.cs18_api_classes import AccessLink
 from gateways.common.cs18_api_errors import SandboxError, Error
-from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel, InsidedTokenResponseModel
-from gateways.common.cs18_api_responses import (
-    SpaceAdmin,
-    SpaceCloudAccount,
-    GetSpacesResponse,
-    CatalogForGetResponse,
-    CatalogForGetAllResponse,
-    BlueprintResponse,
-    CloudAccountResponse,
-    BlueprintInputResponse,
-    SandboxResponse,
-    ProductionBlueResponse, ProductionGreenResponse,
-    SandboxOwnerResponse,
-    SandboxResponseLean,
-    ProductionResponseLean,
-    CloudResponse,
-    ApplicationResponse,
-    ApplicationResponseLean,
-    AppInstanceResponse,
-    HyperlinkResponse,
-    BlueprintApplicationResponse,
-    BlueprintRegionResponse,
-    BlueprintCloudResponse,
-    TokenResponse,
-    CatalogApplicationResponse,
-    UserPermittedToSpaceResponse,
-    SourceControlDetailsResponse,
-    BlueprintFileResponse,
-    UserInvitationResponse,
-    RepositoryResponse,
-    InputResponse,
-    RoleListItemResponse,
-    AccountStatusResponse,
-    ArtifactRepoCreatedUser,
-    AccountStatusUserDetails,
-    ArtifactRepoResponse,
-    UserForAllUsersResponse,
-    ServiceResponse,
-    BlueprintServiceResponse,
-    LaunchingProgress, LaunchingProgressStep, CloudAccountInSpaceResponse, CloudAccountConnectivityResponse,
-    CloudAccountInfraSetResponse, CloudAccountSubnetsResponse, RegionResponse, GetImagesResponse,
-    GetInstanceTypesResponse, VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse,
-    AccountRepositoryResponse, BlueprintValidationResponse, BlueprintSourceResponse, CloudAccountCostResponse,
-    ComputeServiceInAccountResponse, ComputeServiceInSpaceResponse, ComputeServiceSpaceSpecResponse,
-    K8SComputeServiceSpaceInfraSettingsResponse, BlueprintComputeServiceResponse,
-    AccountRepositoryDetailsBranchResponse, AccountRepositoryDetailsResponse,
-    SpaceRepositoryResponse, DirectAwsSshResponse, DirectAzureSshResponse, DirectRdpResponse, ParameterStoreItem,
-    ParameterStoreValue, ParameterStoreOrigin, LiteralValue, AwsSsmValue, CloudRegionResponse,
-    CloudComputeServiceResponse, InvitedUserDetailsResponse, RepositoryProviderResponse, RepositoryRelationshipResponse)
+from gateways.common.cs18_api_requests import AwsCloudProviderSettingsModel
+from gateways.common.cs18_api_responses import (GetSpacesResponse, CreateAccountFinalizeResponse, ParameterStoreItem,
+                                                AwsSsmValue, ParameterStoreOrigin, LiteralValue, ParameterStoreValue,
+                                                DirectRdpResponse, DirectAzureSshResponse,
+                                                DirectAwsSshResponse, SpaceRepositoryResponse,
+                                                BlueprintComputeServiceResponse,
+                                                AccountRepositoryDetailsBranchResponse,
+                                                AccountRepositoryDetailsResponse, VerifyCloudProviderResponse,
+                                                VerifyCloudProviderResourceResponse, GetInstanceTypesResponse,
+                                                GetImagesResponse, RegionResponse,
+                                                LaunchingProgressStep, LaunchingProgress, ServiceResponse,
+                                                AccountExtraDetails, AccountStatusUserDetails,
+                                                AccountOnboardingLimitsResponse, AccountStatusResponse, InputResponse,
+                                                RoleListItemResponse,
+                                                RepositoryRelationshipResponse, AccountRepositoryResponse,
+                                                RepositoryProviderResponse, RepositoryResponse,
+                                                InvitedUserDetailsResponse, UserInvitationResponse,
+                                                BlueprintFileResponse, SourceControlDetailsResponse,
+                                                UserForAllUsersResponse, UserPermittedToSpaceResponse,
+                                                CatalogApplicationResponse, TokenResponse,
+                                                BlueprintCloudResponse, BlueprintRegionResponse,
+                                                BlueprintServiceResponse, BlueprintApplicationResponse,
+                                                HyperlinkResponse, AppInstanceResponse, ApplicationResponseLean,
+                                                ApplicationResponse, CloudResponse,
+                                                CloudComputeServiceResponse, CloudRegionResponse,
+                                                ProductionResponseLean, SandboxResponseLean,
+                                                BlueprintSourceResponse, SandboxOwnerResponse, ProductionGreenResponse,
+                                                ProductionBlueResponse, SandboxResponse,
+                                                BlueprintInputResponse, CloudAccountSubnetsResponse,
+                                                CloudAccountInfraSetResponse, CloudAccountConnectivityResponse,
+                                                CloudAccountInSpaceResponse, CloudAccountResponse,
+                                                K8SComputeServiceSpaceInfraSettingsResponse,
+                                                ComputeServiceSpaceSpecResponse, ComputeServiceInSpaceResponse,
+                                                ComputeServiceInAccountResponse,
+                                                CloudAccountCostResponse, BlueprintResponse,
+                                                BlueprintValidationResponse, ArtifactRepoCreatedUser,
+                                                ArtifactRepoResponse, CatalogForGetAllResponse, CatalogForGetResponse,
+                                                SpaceCloudAccount, SpaceAdmin)
 
 
 class Converters:
@@ -551,7 +540,7 @@ class Converters:
             source=Converters._create_source(sandbox.get('source')),
             direct_access=sandbox.get('direct_access', 'off')
         )
- 
+
     @staticmethod
     def create_production_response_list_item(
             production: dict
@@ -905,6 +894,7 @@ class Converters:
     @staticmethod
     def create_account_status_response(obj: dict):
         return AccountStatusResponse(
+            AccountOnboardingLimitsResponse(obj["limits"]),
             obj["onboarding_status"],
             Converters._parse_datetime(obj["license_expiration_date"]),
             obj["ignore_expiration_date"],
@@ -914,6 +904,17 @@ class Converters:
             AccountStatusUserDetails(obj["user_details"]),
         )
 
+    @staticmethod
+    def create_account_extra_details(json: dict):
+        return AccountExtraDetails(
+            account_id=json['id'],
+            name=json['name'],
+            sso_enabled=json['sso_enabled'],
+            anonymous_users=json['anonymous_users'],
+            sso_update_enabled=json['sso_update_enabled'],
+            company_name=json['company_name'],
+        )
+
     @staticmethod
     def _parse_datetime(value: str) -> datetime:
         if value:
@@ -1074,9 +1075,10 @@ class Converters:
         )
 
     @staticmethod
-    def insided_token_model(data: dict):
-        return InsidedTokenResponseModel(
-            access_token=data.get("access_token", None),
-            token_type=data.get("token_type", None),
-            expires_in=data.get("expires_in", None)
+    def create_create_account_finalize_response(data: dict) -> CreateAccountFinalizeResponse:
+        return CreateAccountFinalizeResponse(
+            account_name=data['account_name'],
+            user_email=data['user_email'],
+            first_name=data['first_name'],
+            last_name=data['last_name']
         )
