@@ -25,11 +25,22 @@ class AccountStatusUserDetails:
         self.email = user_details["email"]
         self.permitted_spaces = user_details["permitted_spaces"]
         self.account_permissions = user_details["account_permissions"]
+        self.survey_done = user_details["survey_done"]
+
+
+class AccountOnboardingLimitsResponse:
+    def __init__(self, limits: {}):
+        self.users = limits["users"]
+        self.users_delta = limits["users_delta"]
+        self.spaces = limits["spaces"]
+        self.environments = limits["environments"]
+        self.environments_delta = limits["environments_delta"]
 
 
 class AccountStatusResponse:
     def __init__(
             self,
+            limits: AccountOnboardingLimitsResponse,
             onboarding_status: str,
             license_expiration_date: datetime,
             ignore_expiration_date: bool,
@@ -38,6 +49,7 @@ class AccountStatusResponse:
             plan_id: str,
             user_details: AccountStatusUserDetails,
     ):
+        self.limits = limits
         self.user_details = user_details  # type: AccountStatusUserDetails
         self.salesforce_account_id = salesforce_account_id
         self.suspended_reason = suspended_reason
@@ -47,6 +59,24 @@ class AccountStatusResponse:
         self.onboarding_status = onboarding_status
 
 
+class AccountExtraDetails:
+    def __init__(
+            self,
+            account_id: str,
+            name: str,
+            sso_enabled: bool,
+            anonymous_users: bool,
+            sso_update_enabled: bool,
+            company_name: str
+    ):
+        self.account_id = account_id
+        self.name = name
+        self.sso_enabled = sso_enabled
+        self.anonymous_users = anonymous_users
+        self.sso_update_enabled = sso_update_enabled
+        self.company_name = company_name
+
+
 class TokenResponse:
     def __init__(
             self, access_token: str, refresh_token: str, token_type: str, expires_in: int
@@ -1133,3 +1163,11 @@ class ParameterStoreItem:
         self.value = value
         self.last_modified = last_modified
         self.modified_by = modified_by
+
+
+class CreateAccountFinalizeResponse:
+    def __init__(self, account_name: str, user_email: str, first_name: str, last_name: str):
+        self.account_name = account_name
+        self.user_email = user_email
+        self.first_name = first_name
+        self.last_name = last_name
